<?php

namespace Drupal\visual_website_optimizer\Render;

use Drupal\Component\Render\MarkupInterface;

/**
 * Render VWO Smart Code javascript without the result being escaped.
 */
class VwoSmartCodeMarkup implements MarkupInterface {

  /**
   * The safe string.
   *
   * @var string
   */
  protected $string;

  /**
   * Create a new VwoSmartCodeMarkup and return it.
   *
   * @param array $settings
   *   Settings used to customize the output.
   *
   * @return \Drupal\Component\Render\MarkupInterface
   *   The VwoSmartCodeMarkup instance.
   */
  public static function createFromArray(array $settings = []) {
    if (!isset($settings['id']) || empty($settings['id'])) {
      return '';
    }

    $safe_string = new static();
    $use_jquery = ($settings['usejquery'] == 'local') ? 'true' : 'false';

    // Setup for custom_url.
    $uri_variable = 'd.URL';
    $custom_url_var = '';
    if (isset($settings['custom_url']) && !empty($settings['custom_url'])) {
      $uri_variable = '_vis_opt_url';
      $custom_url_var = "\n    _vis_opt_url = '{$settings['custom_url']}',";
    }

    // @phpcs:disable
    $safe_string->string = "window._vwo_code || (function() {
  var account_id = {$settings['id']},{$custom_url_var}
    version = 2.0,
    settings_tolerance = {$settings['timeout_setting']},
    library_tolerance = {$settings['timeout_library']},
    use_existing_jquery = {$use_jquery},
    hide_element = 'body',
    hide_element_style = 'opacity:0 !important;filter:alpha(opacity=0) !important;background:none !important',
    /* DO NOT EDIT BELOW THIS LINE */
    f = false,
    w = window,
    d = document,
    v = d.querySelector('#vwoCode'),
    cK = '_vwo_' + account_id + '_settings',
    cc = {};
  try { var c = JSON.parse(localStorage.getItem('_vwo_' + account_id + '_config'));
    cc = c && typeof c === 'object' ? c : {} } catch (e) {}
  var stT = cc.stT === 'session' ? w.sessionStorage : w.localStorage;
  code = { use_existing_jquery: function() { return typeof use_existing_jquery !== 'undefined' ? use_existing_jquery : undefined }, library_tolerance: function() { return typeof library_tolerance !== 'undefined' ? library_tolerance : undefined }, settings_tolerance: function() { return cc.sT || settings_tolerance }, hide_element_style: function() { return '{' + (cc.hES || hide_element_style) + '}' }, hide_element: function() { return typeof cc.hE === 'string' ? cc.hE : hide_element }, getVersion: function() { return version }, finish: function() { if (!f) { f = true; var e = d.getElementById('_vis_opt_path_hides'); if (e) e.parentNode.removeChild(e) } }, finished: function() { return f }, load: function(e) { var t = this.getSettings(),
        n = d.createElement('script'),
        i = this; if (t) { n.textContent = t;
        d.getElementsByTagName('head')[0].appendChild(n); if (!w.VWO || VWO.caE) { stT.removeItem(cK);
          i.load(e) } } else { n.fetchPriority = 'high';
        n.src = e;
        n.type = 'text/javascript';
        n.onerror = function() { _vwo_code.finish() };
        d.getElementsByTagName('head')[0].appendChild(n) } }, getSettings: function() { try { var e = stT.getItem(cK); if (!e) { return } e = JSON.parse(e); if (Date.now() > e.e) { stT.removeItem(cK); return } return e.s } catch (e) { return } }, init: function() { if ({$uri_variable}.indexOf('__vwo_disable__') > -1) return; var e = this.settings_tolerance();
      w._vwo_settings_timer = setTimeout(function() { _vwo_code.finish();
        stT.removeItem(cK) }, e); var t = d.currentScript,
        n = d.createElement('style'),
        i = this.hide_element(),
        r = t && !t.async && i ? i + this.hide_element_style() : '',
        c = d.getElementsByTagName('head')[0];
      n.setAttribute('id', '_vis_opt_path_hides');
      v && n.setAttribute('nonce', v.nonce);
      n.setAttribute('type', 'text/css'); if (n.styleSheet) n.styleSheet.cssText = r;
      else n.appendChild(d.createTextNode(r));
      c.appendChild(n);
      this.load('https://dev.visualwebsiteoptimizer.com/j.php?a=' + account_id + '&u=' + encodeURIComponent({$uri_variable}) + '&vn=' + version) } };
  w._vwo_code = code;
  code.init();
})();";
    // @phpcs:enable

    return $safe_string;
  }

  /**
   * {@inheritdoc}
   */
  public function __toString() {
    return $this->string;
  }

  /**
   * {@inheritdoc}
   */
  public function jsonSerialize(): mixed {
    // Part of interface but not implemented.
    return '';
  }

}
